==> unit-1.0.10-sources.jar: io/intino/goros/unit/box/ui/displays/items/RolesTableNatureItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class RolesTableNatureItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Role, UnitBox> {
	public _49_54_1772043657 _49_54_1772043657;
	public RolesTableNatureItem._49_54_1772043657. Nature nature;

    public RolesTableNatureItem(UnitBox box) {
        super(box);
        id("a_1102436782");
    }

    @Override
	public void init() {
		super.init();
		if (_49_54_1772043657 == null) _49_54_1772043657 = register(new _49_54_1772043657(box()).<_49_54_1772043657>id("a_85840350").owner(RolesTableNatureItem.this));
		if (_49_54_1772043657 != null) nature = _49_54_1772043657.nature;
	}

	public class _49_54_1772043657 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public RolesTableNatureItem._49_54_1772043657. Nature nature;

		public _49_54_1772043657(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (nature == null) nature = register(new Nature(box()).<Nature>id("a328868719").owner(RolesTableNatureItem.this));
		}

		public class Nature extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

			public Nature(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> unit-1.1.7-sources.jar: io/intino/goros/unit/box/ui/displays/items/RolesTableNatureItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class RolesTableNatureItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Role, UnitBox> {
	public _49_54_1772043657 _49_54_1772043657;
	public RolesTableNatureItem._49_54_1772043657. Nature nature;

    public RolesTableNatureItem(UnitBox box) {
        super(box);
        id("a_1102436782");
    }

    @Override
	public void init() {
		super.init();
		if (_49_54_1772043657 == null) _49_54_1772043657 = register(new _49_54_1772043657(box()).<_49_54_1772043657>id("a_85840350").owner(RolesTableNatureItem.this));
		if (_49_54_1772043657 != null) nature = _49_54_1772043657.nature;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_49_54_1772043657 != null) _49_54_1772043657.unregister();
	}

	public class _49_54_1772043657 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public RolesTableNatureItem._49_54_1772043657. Nature nature;

		public _49_54_1772043657(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (nature == null) nature = register(new Nature(box()).<Nature>id("a328868719").owner(RolesTableNatureItem.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (nature != null) nature.unregister();
		}

		public class Nature extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

			public Nature(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}
